@@ -289,7 +289,7 @@ pub trait NetRpc {
     ///     * "192.168.0.2" bans a single IP
     ///     * "192.168.0.0/24" bans IP from "192.168.0.0" to "192.168.0.255".
     /// * `command` - `insert` to insert an IP/Subnet to the list, `delete` to delete an IP/Subnet from the list.
-    /// * `ban_time` - Time in milliseconds how long (or until when if [absolute] is set) the IP is banned, optional parameter, null means using the default time of 24h
+    /// * `ban_time` - Time in milliseconds how long (or until when if \[absolute\] is set) the IP is banned, optional parameter, null means using the default time of 24h
     /// * `absolute` - If set, the `ban_time` must be an absolute timestamp in milliseconds since epoch, optional parameter.
     /// * `reason` - Ban reason, optional parameter.
     ///
@@ -699,8 +699,8 @@ impl NetRpc for NetRpcImpl {
                             .value()
                 };
                 self.network_controller
-                    .ban(ip_network, ban_until, reason.unwrap_or_default())
-                    .map_err(RPCError::ckb_internal_error)
+                    .ban(ip_network, ban_until, reason.unwrap_or_default());
+                Ok(())
             }
             "delete" => {
                 self.network_controller.unban(&ip_network);
